Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1991)

Unified Diff: pkg/ffi/lib/ffi.dart

Issue 1659163007: Rename fletch -> dartino (Closed) Base URL: https://github.com/dartino/sdk.git@master
Patch Set: Created 4 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: pkg/ffi/lib/ffi.dart
diff --git a/pkg/ffi/lib/ffi.dart b/pkg/ffi/lib/ffi.dart
index 814d330cc31144aae222da1a20ddf452ccb3eab3..32f725ccbe2cb018ba7ba2534fd241daf7262b08 100644
--- a/pkg/ffi/lib/ffi.dart
+++ b/pkg/ffi/lib/ffi.dart
@@ -5,17 +5,17 @@
/// Higher level access to the FFI library.
///
/// This package is a set of functions and classes that builds on the lower
/// level FFI library (dart:fletch.ffi).
library ffi;
-import 'dart:fletch.ffi';
+import 'dart:dartino.ffi';
import 'dart:typed_data';
part 'utf.dart';
final ForeignFunction _strlen = ForeignLibrary.main.lookup('strlen');
/// Converts a C string to a String in the Fletch heap.
/// This call expects a null terminated string. The string will be decoded
/// using a UTF8 decoder.
String cStringToString(ForeignPointer ptr) {
@@ -23,7 +23,7 @@ String cStringToString(ForeignPointer ptr) {
return memoryToString(ptr, length);
}
/// Converts a C memory region to a String in the Fletch heap. The string
/// will be decoded using a UTF8 decoder.
String memoryToString(ForeignPointer ptr, int length) {
var memory = new ForeignMemory.fromAddress(ptr.address, length);
@@ -5,17 +5,17 @@
///
/// This package is a set of functions and classes that builds on the lower
-/// level FFI library (dart:fletch.ffi).
+/// level FFI library (dart:dartino.ffi).
library ffi;
@@ -5,17 +5,17 @@
part 'utf.dart';
final ForeignFunction _strlen = ForeignLibrary.main.lookup('strlen');
-/// Converts a C string to a String in the Fletch heap.
+/// Converts a C string to a String in the Dartino heap.
/// This call expects a null terminated string. The string will be decoded
/// using a UTF8 decoder.
@@ -23,7 +23,7 @@ String cStringToString(ForeignPointer ptr) {
return memoryToString(ptr, length);
}
-/// Converts a C memory region to a String in the Fletch heap. The string
+/// Converts a C memory region to a String in the Dartino heap. The string
/// will be decoded using a UTF8 decoder.
String memoryToString(ForeignPointer ptr, int length) {

Powered by Google App Engine
This is Rietveld 408576698